##  Overview
Fact sheet mapping defines which fact sheets and attributes synchronize between SAP LeanIX and Jira Service Management. Each mapping configuration specifies:
  * Source system: Which system serves as the source of truth.
  * Fact sheet types: Which fact sheet types to synchronize.
  * Object types: Which Jira Service Management object types map to SAP LeanIX fact sheets.
  * Field mappings: Which attributes to synchronize between the systems.
